@@ -57,6 +57,7 @@ loadPamguardBinaryFile <- function(fileName, skipLarge=FALSE, skipData=FALSE,
         fileInfo$fileName <- fileName
         fileInfo$readModuleHeader <- readStdModuleHeader
         fileInfo$readModuleFooter <- readStdModuleFooter
+        doneUIDs <- character(0)
         
         # main loop
         while(TRUE) {
@@ -160,6 +161,10 @@ loadPamguardBinaryFile <- function(fileName, skipLarge=FALSE, skipData=FALSE,
                                   fileInfo$objectType <- 1
                                   fileInfo$readModuleData <- readNoiseBandData
                               },
+                              'Gemini Threshold Detector' = {
+                                  fileInfo$objectType <- 0
+                                  fileInfo$readModuleData <- readTritechTrack
+                              },
                               'RW Edge Detector' = {
                                   fileInfo$objectType <- 0
                                   fileInfo$readModuleData <- readRWEDetectorData
@@ -237,12 +242,16 @@ loadPamguardBinaryFile <- function(fileName, skipLarge=FALSE, skipData=FALSE,
                                backgroundData[[nBackground]] <- dataPoint
                                next
                            }
+                           if(dataPoint$UID %in% doneUIDs) {
+                               next
+                           }
                            dataSet[[length(dataSet)+1]] <- dataPoint
+                           doneUIDs <- c(doneUIDs, dataPoint$UID)
                        }
                        # Stop if at end of list of UIDs
                        # MAYBE PROBLEM: This skips the footers.
                        if(length(keepUIDs) > 0 &&
-                          length(keepUIDs)==length(dataSet)) {
+                          all(keepUIDs %in% doneUIDs)) {
                            skipData <- TRUE
                        }
                    }
